%define _unpackaged_files_terminate_build 0

Name: alx-utils
Version: 1.0
Release: 24%{?dist}
Summary: Utilities for Oracle Autonomous Linux
BuildArch: noarch

Group: Development/Tools
URL: http://cloud.oracle.com/iaas
License: UPL
Vendor: Oracle America

Source: %{name}-%{version}.tar.gz

Buildrequires: systemd-rpm-macros
%if 0%{?rhel} <= 8
Buildrequires: checkpolicy selinux-policy-devel
%endif

Conflicts: al-config
Requires: %{name}-libs = %{version}-%{release}
Requires: oracle-cloud-agent
Requires: sos

%if 0%{?rhel} <= 8
Requires: abrt abrt-addon-vmcore abrt-addon-kerneloops abrt-plugin-sosreport abrt-tui
Requires: policycoreutils selinux-policy
Requires: oswatcher >= 9.0.0
%else
Requires: pcp
%endif

%description
This package contains configuration utilities for Oracle Autonomous Linux

%package libs
Summary: Shared libraries for Oracle Autonomous Linux

Requires: python3 python3-pyyaml
Requires: util-linux jq curl procps-ng
Requires: rsyslog kexec-tools
Requires: uptrack

%if 0%{?rhel} <= 8
Requires: python36-oci-cli >= 3.0.3
Requires: libreport
%else
Requires: python39-oci-cli
%endif

%description libs
This package contains shared libraries used by alx-utils

%prep
%autosetup -p1

%build
find . -name ".gitkeep" -delete

%if 0%{?rhel} <= 8
# compile the selinux policy module
# checkmodule -M -m -o alx.mod alx.te
# semodule_package -o alx.pp -m alx.mod
make -f /usr/share/selinux/devel/Makefile alx.pp
%endif

%install
rm -rf %{buildroot}/*
%if 0%{?rhel} >= 9
echo ':msg, contains, "systemd-coredump" /var/lib/alx-utils/oops/events' >> install/etc/rsyslog.d/alx.conf
sed -i '/abrt/d' install/usr/lib/systemd/system-preset/84-alx.preset
%endif
cp -a install/*  %{buildroot}

%if 0%{?rhel} <= 8
install -d %{buildroot}%{_datadir}/selinux/packages
install -m 0644 alx.pp %{buildroot}%{_datadir}/selinux/packages
%endif

%files libs
#/usr/lib
%dir %{_prefix}/lib/%{name}
%attr(644,root,root) %{_prefix}/lib/%{name}/functions
%attr(755,root,root) %{_prefix}/lib/%{name}/activate_known_exploit_detection.sh
%attr(755,root,root) %{_prefix}/lib/%{name}/validate-config
%attr(755,root,root) %{_prefix}/lib/%{name}/check-kernel-reboot-required
%attr(755,root,root) %{_prefix}/lib/%{name}/list-enabled-dnf-repos
%attr(755,root,root) %{_prefix}/lib/%{name}/list-used-dnf-repos
%attr(400,root,root) %{_prefix}/lib/%{name}/ksplice_access_key

%license LICENSE

%files
#/etc
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/alx/alx.conf
%attr(644,root,root) %{_sysconfdir}/logrotate.d/alx
%attr(644,root,root) %{_sysconfdir}/rsyslog.d/alx.conf
%attr(644,root,root) %{_sysconfdir}/profile.d/alx.sh
%attr(644,root,root) %{_sysconfdir}/bash_completion.d/alx
%attr(644,root,root) %{_sysconfdir}/ksplice/blacklist.d/alx.conf
%if 0%{?rhel} <= 8
%attr(644,root,root) %{_sysconfdir}/libreport/events.d/000_alx_koops_event.conf
%attr(644,root,root) %{_sysconfdir}/libreport/events.d/000_alx_vmcore_event.conf
%endif

#/usr/lib
%dir %{_prefix}/lib/%{name}
%attr(644,root,root) %{_prefix}/lib/systemd/system/alx.service
%attr(644,root,root) %{_prefix}/lib/systemd/system-preset/84-alx.preset

#/usr/sbin
%attr(755,root,root) %{_sbindir}/alx

#/usr/share
%if 0%{?rhel} <= 8
%attr(644,root,root) %{_datadir}/selinux/packages/alx.pp
%endif
#/usr/share/man
%attr(644,root,root) %{_mandir}/man1/alx.1*

#/var
%dir %{_sharedstatedir}/%{name}
%if 0%{?rhel} <= 8
%ghost %{_sharedstatedir}/%{name}/alxkoops
%ghost %{_sharedstatedir}/%{name}/alxvmcore
%else
%dir %{_sharedstatedir}/%{name}/oops
%endif

%license LICENSE

%pre

%post

# install or upgrade
%systemd_post alx.service

# install
%if 0%{?rhel} <= 8
if [ $1 -eq 1 ]; then
    # Install selinux module for oops FIFO files
    %{_sbindir}/semodule -i %{_datadir}/selinux/packages/alx.pp || :
fi
%endif

# Initialize
%{_sbindir}/alx init || :

# restart rsyslog to enable KED and coredump log message forwarding
%{_bindir}/systemctl try-restart rsyslog.service >/dev/null 2>&1 || :

%if 0%{?rhel} <= 8
# restart abrtd to enable the abrt event hooks
%{_bindir}/systemctl try-restart abrtd.service >/dev/null 2>&1 || :
%endif

%preun
# uninstall, not upgrade
if [ $1 -eq 0 ]; then
%if 0%{?rhel} <= 8
    # rm -f %{_sharedstatedir}/%{name}/alxkoops %{_sharedstatedir}/%{name}/alxvmcore
    %{_sbindir}/semodule -r alx &>/dev/null || :
%endif
    %{_sbindir}/alx restore || :
fi
%systemd_preun alx.service

%postun
%systemd_postun alx.service

%posttrans

%changelog
* Fri Apr 11 2025 Frank Deng <frank.deng@oracle.com> - 1.0-24
- Set installonly_limit to 2 in yum/dnf config

* Thu Nov 5 2024 Frank Deng <frank.deng@oracle.com> - 1.0-23
- AL9 support
- Ksplice blacklist OCA unified-monitoring-agent

* Thu Apr 4 2024 Frank Deng <frank.deng@oracle.com> - 1.0-22
- Add OS Management Hub support

* Mon Aug 29 2022 Frank Deng <frank.deng@oracle.com> - 1.0-21
- Initial OL8 build (Frank Deng <frank.deng@oracle.com>)
- DNF repo utilities for OL8 (Saige Madden <saige.madden@oracle.com>)
- abrt configuration for OL8 (Manuel Esparza <manuel.e.esparza@oracle.com>)
